==> vtigercrm-5.3.0p0.tgz: modules/Home/language/es_es.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 ********************************************************************************
*  Module       : Home
*  Language     : Español
*  Version      : 504
*  Created Date : 2007-03-30
*  Author       : Rafael Soler
*  Last change  : 2008-09-20
*  Author       : Joe Bordes JPL TSolucio, S.L.
 ********************************************************************************/

$mod_strings = Array(
'LBL_NEW_FORM_TITLE'=>'Nuevo Contacto',
'LBL_FIRST_NAME'=>'Nombre:',
'LBL_LAST_NAME'=>'Apellidos:',
'LBL_LIST_LAST_NAME'=>'Apellidos',
'LBL_ACCOUNT_NAME'=>'Nombre de la Cuenta:',
'LBL_LIST_ACCOUNT_NAME'=>'Nombre de la Cuenta',
'LBL_PHONE'=>'Teléfono:',
'LBL_EMAIL_ADDRESS'=>'E-mail:',
'LBL_TOTAL'=>'Total: ',

'LBL_MY_HOME'=>'Mi Inicio',
'LBL_MODIFIED_TIME'=>'Fecha de Modificación',
'LBL_LOGIN_ID'=>'ID',
'LBL_MODIFIED_BY'=>'Modificado Por',
'LBL_TYPE'=>'Tipo',

'LBL_PIPELINE_FORM_TITLE'=>'Mis Oportunidades',

'ERR_ONE_CHAR'=>'Por favor, introduzca al menos una letra o número para efectuar la búsqueda...',

'LBL_OPEN_TASKS'=>'Mis tareas abiertas',

'LBL_LEADS_BY_SOURCE'=>'Pre-Contactos Por Origen',
'LBL_LEADS_BY_STATUS'=>'Pre-Contactos Por Estado',

'LBL_UPCOMING_EVENTS'=>'Próximos Eventos',
'LBL_PENDING_EVENTS'=>'Eventos Pendientes',
'LBL_SINGLE_PENDING_EVENT'=>'Eventos de los últimos 10 días',
'LBL_MULTIPLE_PENDING_EVENTS'=>'Eventos de los últimos 10 días',

'recordsforuser'=>'Registros por',

'Today'=>'Hoy',
'This Week'=>'Esta Semana',
'This Month'=>'Este Mes',
'This Year'=>'Este Año',
'Last Week'=>'Esta Semana',
'Last 2 Days'=>'Últimos 2 días',
'Last Ten Days'=>'Últimos 10 días',
// Added/Updated for vtiger CRM 5.0.4 
'TITLE_AJAX_CSS_POPUP_CHAT'=>'Chat',
'User List'=>'Lista de Usuarios',

// Added after 5.0.4 GA

//ADDED for Home Page Customization
'LBL_HOME_MODULE' => 'Módulo',
'LBL_HOME_RSS' => 'RSS',
'LBL_HOME_DASHBOARD' => 'Análisis',
'LBL_HOME_STUFFTITLE'=>'Título Ventana',
'LBL_HOME_SHOW'=>'Mostrar',
'LBL_HOME_FILTERBY'=>'Filtrar Por',
'LBL_HOME_Fields'=>'Campos a Mostrar <br>(selecciona dos)',
'LBL_HOME_PRESSCTRL'=>'(Pulsa "Ctrl" <br> para seleccionar varios)',
'LBL_HOME_RSSURL'=>'RSS URL',
'LBL_HOME_DASHBOARD_NAME'=>'Nombre Análisis', 
'LBL_HOME_DASHBOARD_TYPE'=>'Tipo Análisis',
'LBL_HOME_HORIZONTAL_BARCHART'=>'Gráfico Barras Horizontal',
'LBL_HOME_VERTICAL_BARCHART'=>'Gráfico Barras Vertical',
'LBL_HOME_PIE_CHART'=>'Gráfico Tarta',
'LBL_HOME_ITEMS'=>'elemento(s)',
'LBL_MORE'=>'Más',
'LBL_SCROLL'=>'Desplazar',

// vtiger CRM News
'LBL_NEWS_NO'=>'Sín Noticias',

//added for home page changes
'LBL_NOTEBOOK'=>'Notas',
'LBL_NOTEBOOK_TITLE'=>'Doble-click para editar.',
'LBL_NOTEBOOK_SAVE_TITLE'=>'Pulse en cualquier otra parte para guardar.',

'LBL_URL'=>'Sitio Web',
'LBL_HOME_LAYOUT'=>'Cambia disposición',
'LBL_NUMBER_OF_COLUMNS'=>'Número de columnas',
'LBL_TWO_COLUMN'=>'Dos Columnas',
'LBL_THREE_COLUMN'=>'Tres Columnas',
'LBL_FOUR_COLUMN'=>'Cuatro Columnas',
// END

// Default home page widget's title
'Top Accounts'=>'Cuentas Importantes',
'Top Potentials'=>'Potenciales Importantes',
'Top Quotes'=>'Presupuestos Importantes',
'Top Trouble Tickets'=>'Incidencias Importantes',
'Top Invoices'=>'Facturas Importantes',
'Top Sales Orders'=>'Orden Venta Importantes',
'Top Purchase Orders'=>'Orden Compra Importantes',
'My New Leads'=>'Nuevos PreContactos',
'Key Metrics'=>'Medidas Clave',
'My Group Allocation'=>'Asignación de Grupo',
'My Recent FAQs'=>'FAQs Recientes',
'Upcoming Activities'=>'Próximas Actividades',
'Pending Activities'=>'Actividades Pendientes',
'Home Page Dashboard'=>'Cuadro Mando Inicio',
'Tag Cloud'=>'Nube Etiquetas',

'MSG_NO_FILTERS' => 'Ningún Filtro Disponible',
'MSG_NO_FIELDS' => 'Ningún Campo Disponible',

);

?>

==> vtigercrm-5.4.0.tgz: modules/Home/language/es_es.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 ********************************************************************************
*  Module       : Home
*  Language     : Español
*  Version      : 5.4.0
*  Created Date : 2007-03-30
*  Author       : Rafael Soler
*  Last change  : 2012-02-27
*  Author       : Joe Bordes JPL TSolucio, S.L.
 ********************************************************************************/

$mod_strings = Array(
'LBL_NEW_FORM_TITLE'=>'Nuevo Contacto',
'LBL_FIRST_NAME'=>'Nombre:',
'LBL_LAST_NAME'=>'Apellidos:',
'LBL_LIST_LAST_NAME'=>'Apellidos',
'LBL_ACCOUNT_NAME'=>'Nombre de la Cuenta:',
'LBL_LIST_ACCOUNT_NAME'=>'Nombre de la Cuenta',
'LBL_PHONE'=>'Teléfono:',
'LBL_EMAIL_ADDRESS'=>'E-mail:',
'LBL_TOTAL'=>'Total: ',

'LBL_MY_HOME'=>'Mi Inicio',
'LBL_MODIFIED_TIME'=>'Fecha de Modificación',
'LBL_LOGIN_ID'=>'ID',
'LBL_MODIFIED_BY'=>'Modificado Por',
'LBL_TYPE'=>'Tipo',

'LBL_PIPELINE_FORM_TITLE'=>'Mis Oportunidades',

'ERR_ONE_CHAR'=>'Por favor, introduzca al menos una letra o número para efectuar la búsqueda...',

'LBL_OPEN_TASKS'=>'Mis tareas abiertas',

'LBL_LEADS_BY_SOURCE'=>'Pre-Contactos Por Origen',
'LBL_LEADS_BY_STATUS'=>'Pre-Contactos Por Estado',

'LBL_UPCOMING_EVENTS'=>'Próximos Eventos',
'LBL_PENDING_EVENTS'=>'Eventos Pendientes',
'LBL_SINGLE_PENDING_EVENT'=>'Eventos de los últimos 10 días',
'LBL_MULTIPLE_PENDING_EVENTS'=>'Eventos de los últimos 10 días',

'recordsforuser'=>'Registros por',

'Today'=>'Hoy',
'This Week'=>'Esta Semana',
'This Month'=>'Este Mes',
'This Year'=>'Este Año',
'Last Week'=>'Esta Semana',
'Last 2 Days'=>'Últimos 2 días',
'Last Ten Days'=>'Últimos 10 días',
// Added/Updated for vtiger CRM 5.0.4 
'TITLE_AJAX_CSS_POPUP_CHAT'=>'Chat',
'User List'=>'Lista de Usuarios',

// Added after 5.0.4 GA

//ADDED for Home Page Customization
'LBL_HOME_MODULE' => 'Módulo',
'LBL_HOME_RSS' => 'RSS',
'LBL_HOME_DASHBOARD' => 'Análisis',
'LBL_HOME_STUFFTITLE'=>'Título Ventana',
'LBL_HOME_SHOW'=>'Mostrar',
'LBL_HOME_FILTERBY'=>'Filtrar Por',
'LBL_HOME_Fields'=>'Campos a Mostrar <br>(selecciona dos)',
'LBL_HOME_PRESSCTRL'=>'(Pulsa "Ctrl" <br> para seleccionar varios)',
'LBL_HOME_RSSURL'=>'RSS URL',
'LBL_HOME_DASHBOARD_NAME'=>'Nombre Análisis', 
'LBL_HOME_DASHBOARD_TYPE'=>'Tipo Análisis',
'LBL_HOME_HORIZONTAL_BARCHART'=>'Gráfico Barras Horizontal',
'LBL_HOME_VERTICAL_BARCHART'=>'Gráfico Barras Vertical',
'LBL_HOME_PIE_CHART'=>'Gráfico Tarta',
'LBL_HOME_ITEMS'=>'elemento(s)',
'LBL_MORE'=>'Más',
'LBL_SCROLL'=>'Desplazar',

// vtiger CRM News
'LBL_NEWS_NO'=>'Sín Noticias',

//added for home page changes
'LBL_NOTEBOOK'=>'Notas',
'LBL_NOTEBOOK_TITLE'=>'Doble-click para editar.',
'LBL_NOTEBOOK_SAVE_TITLE'=>'Pulse en cualquier otra parte para guardar.',

'LBL_URL'=>'Sitio Web',
'LBL_HOME_LAYOUT'=>'Cambia disposición',
'LBL_NUMBER_OF_COLUMNS'=>'Número de columnas',
'LBL_TWO_COLUMN'=>'Dos Columnas',
'LBL_THREE_COLUMN'=>'Tres Columnas',
'LBL_FOUR_COLUMN'=>'Cuatro Columnas',
// END

// Default home page widget's title
'Top Accounts'=>'Cuentas Importantes',
'Top Potentials'=>'Potenciales Importantes',
'Top Quotes'=>'Presupuestos Importantes',
'Top Trouble Tickets'=>'Incidencias Importantes',
'Top Invoices'=>'Facturas Importantes',
'Top Sales Orders'=>'Orden Venta Importantes',
'Top Purchase Orders'=>'Orden Compra Importantes',
'My New Leads'=>'Nuevos PreContactos',
'Key Metrics'=>'Medidas Clave',
'My Group Allocation'=>'Asignación de Grupo',
'My Recent FAQs'=>'FAQs Recientes',
'Upcoming Activities'=>'Próximas Actividades',
'Pending Activities'=>'Actividades Pendientes',
'Home Page Dashboard'=>'Cuadro Mando Inicio',
'Tag Cloud'=>'Nube Etiquetas',

'MSG_NO_FILTERS' => 'Ningún Filtro Disponible',
'MSG_NO_FIELDS' => 'Ningún Campo Disponible',

//Customization Phase 6 -- Monolithic
'LBL_REPORTCHARTS' => 'Informes Gráficos',
'LBL_HOME_REPORT_NAME'=> 'Nombre Informe',
'LBL_HOME_REPORT_TYPE' => 'Tipo Informe',
//END

//added for Default Widgets
'LBL_DEFAULT_WIDGET'=>'Widgets por Defecto',
'LBL_NO_WIDGETS_HIDDEN'=>'No hay widgets escondidos',

);

?>
